@@ -54,6 +54,11 @@ def getstrval(v):
         return v.rule()
     return str(v)
 
+def ne(name, type):
+    return [name, type]
+
+def mwe(name, lemma, signature):
+    return [name, lemma, signature]
 
 def valence_rule(lemma="", pos=""):
     return f"lemma={lemma},pos2={getstrval(pos)},node=concept|sit"
